@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.014-1-gafa4273
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.015-16-g0485a67
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
-# vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.015';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.016';
+
 use Moose;
 use MooseX::Types;
 use MooseX::Types::Moose 'ArrayRef';
@@ -16,6 +18,7 @@ with
 
 use Dist::Zilla::Plugin::ModuleBuild;
 use Dist::Zilla::Plugin::ModuleBuildTiny;
+use Moose::Util 'find_meta';
 use List::Util 'first';
 use Scalar::Util 'blessed';
 use namespace::autoclean;
@@ -60,7 +63,7 @@ around dump_config => sub
                 my $plugin = $_;
                 my $config = $plugin->dump_config;
                 +{
-                    class   => $plugin->meta->name,
+                    class   => find_meta($plugin)->name,
                     name    => $plugin->plugin_name,
                     version => $plugin->VERSION,
                     (keys %$config ? (config => $config) : ()),
@@ -160,6 +163,11 @@ sub setup_installer
         || first { $_->name eq 'Build.PL' } @{ $self->zilla->files };
     my $mbt_content = $mbt_build_pl->content;
 
+    # extract everything added to the head of the file, to put back on top
+    # when we are done -- we presume this is content or code meant to stay on top
+    $mbt_content =~ s/\A(.*)(\Q# This Build.PL for ${\ $self->zilla->name }\E)/$2/s;
+    my $preamble = $1;
+
     # comment out the 'use' line; adjust preamble comments
     $mbt_content =~ s/^(use Module::Build::Tiny [\d.]+;)$/# $1/m;
     $mbt_content =~ s/This (?:Build.PL|file) /This section /;
@@ -178,9 +186,10 @@ sub setup_installer
     delete @{$configure_requires}{ grep { not version::is_strict($configure_requires->{$_}) } keys %$configure_requires };
 
     $mbt_build_pl->content(
-        <<"FALLBACK1"
+        ( defined $preamble ? $preamble : '' )
+        . <<"FALLBACK1"
 # This Build.PL for ${\ $self->zilla->name } was generated by
-# ${\ ref $self } ${ \($self->VERSION || '<self>') }
+# ${\ ref $self } ${ \($self->VERSION) }
 use strict;
 use warnings;
 
@@ -203,10 +212,13 @@ FALLBACK2
 $mbt_content}
 else
 {
-    \$ENV{PERL_MB_FALLBACK_SILENCE_WARNING} or warn <<'EOW';
+    if (\$ENV{PERL_MB_FALLBACK_SILENCE_WARNING})
+    {
+        warn <<'EOW';
 $message
 EOW
-    sleep 10 if -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
+        sleep 10 if -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
+    }
 
 $mb_content}
 FALLBACK3
@@ -340,7 +352,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
